@@ -154,11 +154,4 @@ mod tests {
             AttributeValue::String("foo bar".to_string())
         );
     }
-
-    enum Foo {}
-    impl AsRef<str> for Foo {
-        fn as_ref(&self) -> &'static str {
-            //
-        }
-    }
 }
